@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmPfTable.cc 9415 2017-06-03 23:04:48Z dwm $
+// @(#) $Id: DwmPfTable.cc 12347 2024-05-03 02:40:01Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -58,7 +58,7 @@ extern "C" {
 #include "DwmSysLogger.hh"
 #include "DwmPfDevice.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmPf/tags/libDwmPf-0.1.3/src/DwmPfTable.cc 9415 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmPf/tags/libDwmPf-0.1.6/src/DwmPfTable.cc 12347 $");
 
 using namespace std;
 
@@ -105,8 +105,13 @@ namespace Dwm {
       if (iocTable._tbl.pfrio_buffer && iocTable._tbl.pfrio_size) {
         _tbl.pfrio_buffer =
           malloc(iocTable._tbl.pfrio_size * iocTable._tbl.pfrio_esize);
-        memcpy(_tbl.pfrio_buffer, iocTable._tbl.pfrio_buffer,
-               iocTable._tbl.pfrio_size * iocTable._tbl.pfrio_esize);
+        if (nullptr != _tbl.pfrio_buffer) {
+          memcpy(_tbl.pfrio_buffer, iocTable._tbl.pfrio_buffer,
+                 iocTable._tbl.pfrio_size * iocTable._tbl.pfrio_esize);
+        }
+        else {
+          throw std::bad_alloc();
+        }
       }
     }
 
@@ -116,13 +121,20 @@ namespace Dwm {
     Table::IOCTable &
     Table::IOCTable::operator = (const Table::IOCTable & iocTable)
     {
+      Syslog(LOG_DEBUG, "IOCTable::operator = called");
       if (&iocTable != this) {
+        ClearBuffer();
         memcpy(&_tbl, &iocTable._tbl, sizeof(_tbl));
         if (iocTable._tbl.pfrio_buffer && iocTable._tbl.pfrio_size) {
           _tbl.pfrio_buffer =
             malloc(iocTable._tbl.pfrio_size * iocTable._tbl.pfrio_esize);
-          memcpy(_tbl.pfrio_buffer, iocTable._tbl.pfrio_buffer,
-                 iocTable._tbl.pfrio_size * iocTable._tbl.pfrio_esize);
+          if (nullptr != _tbl.pfrio_buffer) {
+            memcpy(_tbl.pfrio_buffer, iocTable._tbl.pfrio_buffer,
+                   iocTable._tbl.pfrio_size * iocTable._tbl.pfrio_esize);
+          }
+          else {
+            throw std::bad_alloc();
+          }
         }
       }
       return *this;
@@ -320,6 +332,10 @@ namespace Dwm {
             Syslog(LOG_DEBUG, "Added %s to %s",
                    prefix.ToShortString().c_str(), _name.c_str());
           }
+          else {
+            Syslog(LOG_ERR, "Failed to add %s to %s",
+                   prefix.ToShortString().c_str(), _name.c_str());
+          }
         }
       }
       else {
